#!/usr/bin/env python
# coding: utf-8

# In[34]:


import tkinter as tk
from tkinter.filedialog import asksaveasfile
from PIL import Image, ImageTk
import math

# Layout constants.
MARGIN = 5
WINDOW_WID = 400
WINDOW_HGT = 300

class ScribbleApp:
    # Create and manage the tkinter interface.
    def __init__(self):
        # Make the main interface.
        self.window = tk.Tk()
        self.window.title('Scribble')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry(f'{WINDOW_WID}x{WINDOW_HGT}')

        # Build the menus.
        self.build_menus()

        # Build the rest of the UI here...
        self.canvas = tk.Canvas(self.window, bg='white', cursor='cross',
            borderwidth=2, relief=tk.SUNKEN)
        self.canvas.pack(padx=10, pady=(0, 10),
            side=tk.BOTTOM, fill=tk.BOTH, expand=True)

        # Initially we are not drawing a line.
        self.line_points = None
        self.current_line = None
        self.num_lines = 0
        self.line_colors = ['red', 'green', 'blue', 'black', 'purple', 'orange']

        # Track Button-1 down, Button-1 motion, and Button-1 up.
        self.canvas.bind("<Button-1>", self.mouse_down)
        self.canvas.bind("<B1-Motion>", self.mouse_move)
        self.canvas.bind("<ButtonRelease-1>", self.mouse_up)

        # Display the window.
        self.window.focus_force()
        self.window.mainloop()

    def build_menus(self):
        '''Build the menu bar.'''
        menu_bar = tk.Menu(self.window)
        self.window.config(menu=menu_bar)

        self.build_file_menu(menu_bar)

    def build_file_menu(self, menu_bar):
        '''Build the File menu.'''
        file_menu = tk.Menu(menu_bar, tearoff=False)
        menu_bar.add_cascade(label='File', menu=file_menu)

        # New
        self.new_photo_image = ImageTk.PhotoImage(file='new.png')
        file_menu.add_command(label='New', accelerator='Ctrl+N', compound='left',
            command=self.mnu_new, image=self.new_photo_image)
        self.window.bind('<Control-n>', lambda event: self.mnu_new())

        file_menu.add_separator()

        # Exit
        self.exit_photo_image = ImageTk.PhotoImage(file='exit.png')
        file_menu.add_command(label='Exit', compound='left',
            command=self.mnu_exit, image=self.exit_photo_image)

    def mnu_new(self):
        '''Delete all lines.'''
        self.canvas.delete(tk.ALL)

    def mnu_exit(self):
        print('Exit')
        self.kill_callback()

    def kill_callback(self):
        self.window.destroy()

    def mouse_down(self, event):
        '''Record the line's starting point.'''
        self.line_points = [(event.x, event.y)]

    def mouse_move(self, event):
        # Ignore extraneous events.
        if self.line_points is None: return

        # If there is a current line, remove it.
        if self.current_line is not None:
            self.canvas.delete(self.current_line)

        # Create a line.
        self.line_points.append((event.x, event.y))
        color = self.line_colors[self.num_lines % len(self.line_colors)]
        self.current_line = self.canvas.create_line(self.line_points, fill=color)

    def mouse_up(self, event):
        # Ignore extraneous events.
        if self.line_points is None: return

        # We are no longer creating a line.
        self.line_points = None
        self.current_line = None
        self.num_lines += 1


# In[35]:


ScribbleApp()
print('Done')


# In[ ]:




